import { createElement, Fragment } from 'react';
import { Stack, HStack, IconButton, Button } from '@chakra-ui/react';
import { ChevronLeftIcon, ChevronRightIcon } from '@chakra-ui/icons';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var _excluded = ["count", "pageSize", "page", "onPageChange", "margin", "size", "selectedVariant", "variant", "previousIcon", "nextIcon", "colorScheme", "fontWeight", "borderRadius"];
var Paginate = function Paginate(props) {
  var count = props.count,
      pageSize = props.pageSize,
      page = props.page,
      onPageChange = props.onPageChange,
      _props$margin = props.margin,
      margin = _props$margin === void 0 ? 1 : _props$margin,
      _props$size = props.size,
      size = _props$size === void 0 ? "md" : _props$size,
      _props$selectedVarian = props.selectedVariant,
      selectedVariant = _props$selectedVarian === void 0 ? "solid" : _props$selectedVarian,
      _props$variant = props.variant,
      variant = _props$variant === void 0 ? "outline" : _props$variant,
      _props$previousIcon = props.previousIcon,
      previousIcon = _props$previousIcon === void 0 ? createElement(ChevronLeftIcon, null) : _props$previousIcon,
      _props$nextIcon = props.nextIcon,
      nextIcon = _props$nextIcon === void 0 ? createElement(ChevronRightIcon, null) : _props$nextIcon,
      _props$colorScheme = props.colorScheme,
      colorScheme = _props$colorScheme === void 0 ? "gray" : _props$colorScheme,
      _props$fontWeight = props.fontWeight,
      fontWeight = _props$fontWeight === void 0 ? "regular" : _props$fontWeight,
      _props$borderRadius = props.borderRadius,
      borderRadius = _props$borderRadius === void 0 ? "md" : _props$borderRadius,
      rest = _objectWithoutPropertiesLoose(props, _excluded);

  var numberOfPages = Math.ceil(count / pageSize);

  var handlePageClick = function handlePageClick(i) {
    var newPage = i;

    if (i >= numberOfPages - 1) {
      newPage = numberOfPages - 1;
    } else if (i <= 0) {
      newPage = 0;
    }

    onPageChange(newPage);
  };

  var shouldRender = function shouldRender(idx) {
    return idx == page || Math.abs(idx - page) <= margin || idx === numberOfPages - 1 || idx === 0;
  };

  var shouldRenderEllipsis = function shouldRenderEllipsis(idx) {
    return idx == page || Math.abs(idx - page) === margin + 1;
  };

  return createElement(Stack, {
    p: 5
  }, createElement(HStack, null, createElement(IconButton, Object.assign({}, rest, {
    fontWeight: fontWeight,
    borderRadius: borderRadius,
    size: size,
    variant: variant,
    "aria-label": "previous",
    icon: previousIcon,
    onClick: function onClick(e) {
      e.preventDefault();
      handlePageClick(page - 1);
    },
    colorScheme: colorScheme
  })), Array(numberOfPages).fill(0).map(function (_, i) {
    return shouldRender(i) ? createElement(Button, Object.assign({
      key: i
    }, rest, {
      fontWeight: fontWeight,
      borderRadius: borderRadius,
      size: size,
      variant: page == i ? selectedVariant : variant,
      onClick: function onClick(e) {
        e.preventDefault();
        handlePageClick(i);
      },
      colorScheme: colorScheme
    }), i + 1) : shouldRenderEllipsis(i) ? createElement(Button, Object.assign({
      key: i
    }, rest, {
      fontWeight: fontWeight,
      borderRadius: borderRadius,
      size: size,
      variant: variant,
      pointerEvents: "none",
      colorScheme: colorScheme
    }), "...") : createElement(Fragment, {
      key: i
    });
  }), createElement(IconButton, Object.assign({}, rest, {
    fontWeight: fontWeight,
    borderRadius: borderRadius,
    "aria-label": "next",
    icon: nextIcon,
    onClick: function onClick(e) {
      e.preventDefault();
      handlePageClick(page + 1);
    },
    size: size,
    variant: variant,
    colorScheme: colorScheme
  }))));
};

export { Paginate };
//# sourceMappingURL=react-paginate-chakra-ui.esm.js.map
